OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visor",
    "Simple file viewer with slideshow for media" : "Visor de ficheiros sinxelo con diaporama para multimedia",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Presente as fotos e vídeos das súas vacacións como nos filmes, amose un adianto da súa novela directamente dende a súa nube, escolla as mellores imaxes GIF da súa colección grazas á vista previa dos seus ficheiros favoritos, e moito máis!",
    "Error loading {name}" : "Produciuse un erro ao cargar {name}",
    "Your browser does not support the video tag." : "O seu navegador non admite a etiqueta para vídeos",
    "Open sidebar" : "Abrir a barra lateral",
    "View" : "Ver",
    "Share" : "Compartir"
},
"nplurals=2; plural=(n != 1);");
